@@ -171,7 +171,7 @@ export class CellMetadataEditor extends React.Component<IProps, IState> {
     }
 
     updateTransformerEnabled = (settings: ISettingRegistry.ISettings): void => {
-        this.setState({isTransformerEnabled: getTransformerEnabled(settings)});
+        this.setState({isTransformerEnabled: getTransformerEnabled()});
     };
 
     checkCellCodeDefinitionConfirmed = (notebook: Notebook, cellIndex: number, tag: string) => {
